;; Generated package description from consult-flycheck.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "consult-flycheck" "1.1.0.20260517.211429" "Provides the command `consult-flycheck'" '((emacs "29.1") (consult "2.8") (flycheck "35")) :commit "f9630b7cdc7da4d0ca52134083de8ea2f1a4506d" :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("languages" "tools" "completion") :url "https://github.com/minad/consult-flycheck")
